@@ -8,7 +8,7 @@
 """ """
 
 import json
-import logging
+import logging.config
 from pathlib import Path
 from typing import Union, List, Dict
 
@@ -20,11 +20,11 @@ except ImportError:
     import importlib_resources as pkg_resources
 import fingerprint_report_templates
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger('fingerprinter')
 
 
 def generate_endpoint_fingerprint_report(sparql_endpoint_url: str, output_location: Union[str, Path],
-                                         selected_graphs: List[str] = [""],
+                                         selected_graphs: List[str] = None,
                                          external_template_location: Union[str, Path] = None) -> str:
     """
         Calculate the fingerprint of a given endpoint and write the report in the output location.
@@ -35,6 +35,10 @@ def generate_endpoint_fingerprint_report(sparql_endpoint_url: str, output_locati
     :param external_template_location: location of custom template (if None -> use the default template)
     :return: path to the main report document
     """
+    logger.debug('start generating fingerprinting report from endpoint')
+    if not selected_graphs:
+        selected_graphs = ['']
+
     location = Path(output_location)
     if not location.exists() or not location.is_dir():
         raise NotADirectoryError("The output location must be a folder")
@@ -47,6 +51,7 @@ def generate_endpoint_fingerprint_report(sparql_endpoint_url: str, output_locati
     report_builder = ReportBuilder(target_path=template_location, additional_config=updated_config_content,
                                    output_path=location)
     report_builder.make_document()
+    logger.debug('end generating fingerprinting report from endpoint')
     return location / updated_config_content["template"]
 
 
@@ -59,10 +64,12 @@ def generate_report_builder_config(sparql_endpoint_url: str, selected_graphs: Li
     :param external_template_location: location of the custom template
     :return: the new configuration
     """
+    logger.debug('start generating report builder config')
     template_location = external_template_location if external_template_location else \
         pkg_resources.path(fingerprint_report_templates, "fingerprint_report").__enter__()
 
     config_dict = json.loads((Path(template_location) / "config.json").read_bytes())
     config_dict["conf"]["default_endpoint"] = sparql_endpoint_url
     config_dict["conf"]["selected_graphs"] = selected_graphs
+    logger.debug('end generating report builder config')
     return config_dict
